@@ -5,7 +5,7 @@ echo "" 												>> $EXTENSION/build_order.txt
 # Required
 [ ! -f /lib/libtalloc.so ] && echo "Installing talloc" && extension --install talloc && echo "Finished talloc"
 # Recommended
-if [[ $INSTALL_RECOMMENDED != false ]]; then 
+if [[ $INSTALL_OPTIONAL != false ]]; then 
 	[[ $(command -v krb5-config) == "" ]] && echo "Installing mit_kerberos_v5" && extension --install mit_kerberos_v5 && echo "Finished mit_kerberos_v5"
 	[[ $(command -v docutils) == "" ]] && echo "Installing py_docutils" && extension --install py_docutils && echo "Finished py_docutils"
 	[[ $(command -v keyctl) == "" ]] && echo "Installing keyutils" && extension --install keyutils && echo "Finished keyutils"
@@ -14,7 +14,7 @@ if [[ $INSTALL_RECOMMENDED != false ]]; then
 	[ ! -f /lib/pam_cap.so ] && echo "Installing libcap" && extension --install libcap && echo "Finished libcap"
 fi
 
-if [ $BUILD_ALL == "false" ] && [[ $(command -v smbinfo) == "" ]]; then
+if [ $BUILD_ALL == "false" ] && [[ $(cat /etc/extension/installed_version.list | grep cifs_utils=7.2) == "" ]]; then
 	echo "cifs_utils" 									>> $EXTENSION/build_order.txt
 fi
 if [ $BUILD_ALL == "true" ]; then
