@@ -2,10 +2,9 @@ DESCRIPTION="SMB/CIFS share support"
 
 [ $(gcc -dumpversion | cut -d "." -f 1) == 15 ] &&  autoreconf -fiv
 
-[ -f /lib/libpam.so ] && PAM_SUPPORT="--with-pamdir" || PAM_SUPPORT="--with-pamdir=/usr/lib/security"
+[ -f /lib/libpam.so ] && PAM_SUPPORT="--with-pamdir=/usr/lib/security" || PAM_SUPPORT="--disable-pam"
 
-./configure --prefix=/usr \
-            $PAM_SUPPORT
+./configure --prefix=/usr $PAM_SUPPORT
 # --disable-pam: Do not build PAM support. Remove it and use --with-pamdir (see below), if Linux-PAM-1.6.0 is installed and you wish PAM support.
 # --with-pamdir=/usr/lib/security: Install the PAM module in /usr/lib/security.
 
